summaryrefslogtreecommitdiff
path: root/src/core/managed/Managed.hpp
diff options
context:
space:
mode:
authorAndreas Stöckel <astoecke@techfak.uni-bielefeld.de>2015-01-11 13:23:26 +0100
committerAndreas Stöckel <astoecke@techfak.uni-bielefeld.de>2015-01-11 13:23:26 +0100
commit7df5f30494b7da283164717dea9098c8d9dca77a (patch)
tree8d967f3c47fc905b08ee7039b7549253f969703f /src/core/managed/Managed.hpp
parent3d6d42333a49e0a33a8cc4e1b8f890905a435a83 (diff)
Renamed RttiBase to RttiType
Diffstat (limited to 'src/core/managed/Managed.hpp')
-rw-r--r--src/core/managed/Managed.hpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/core/managed/Managed.hpp b/src/core/managed/Managed.hpp
index f7eaa48..8ad609f 100644
--- a/src/core/managed/Managed.hpp
+++ b/src/core/managed/Managed.hpp
@@ -41,7 +41,7 @@ class Rooted;
template <class T>
class Owned;
-class RttiBase;
+class RttiType;
// TODO: Implement clone, getReferenced and getReferencing
@@ -190,32 +190,32 @@ public:
/* RTTI methods */
/**
* Returns the RttiBase instance registered for instances of the type of
* this Managed instance.
*
* @return a reference to the registered RttiBase for this particular
* Managed class.
*/
- const RttiBase &type() const;
+ const RttiType &type() const;
/**
* Returns true if this Managed instance is of the type described by the
* given RttiBase instance.
*
* @param true if the RttiBase registered for this particular Managed
* class is of the given type or one of the registered parent types is of
* the given type.
*/
- bool isa(const RttiBase &t) const;
+ bool isa(const RttiType &t) const;
/**
* Returns true if this Managed instance may contain instances of the type
* described by the given RttiBase instance.
*
* @param true if the RttiBase registered for this particular Managed class
* may contain instance of the given type.
*/
- bool composedOf(const RttiBase &t) const;
+ bool composedOf(const RttiType &t) const;
};
/**
@@ -190,32 +190,32 @@ public:
/* RTTI methods */
/**
- * Returns the RttiBase instance registered for instances of the type of
+ * Returns the RttiType instance registered for instances of the type of
* this Managed instance.
*
@@ -190,32 +190,32 @@ public:
* this Managed instance.
*
- * @return a reference to the registered RttiBase for this particular
+ * @return a reference to the registered RttiType for this particular
* Managed class.
*/
@@ -190,32 +190,32 @@ public:
/**
* Returns true if this Managed instance is of the type described by the
- * given RttiBase instance.
+ * given RttiType instance.
*
@@ -190,32 +190,32 @@ public:
*
- * @param true if the RttiBase registered for this particular Managed
+ * @param true if the RttiType registered for this particular Managed
* class is of the given type or one of the registered parent types is of
* the given type.
@@ -190,32 +190,32 @@ public:
/**
* Returns true if this Managed instance may contain instances of the type
- * described by the given RttiBase instance.
+ * described by the given RttiType instance.
*
@@ -190,32 +190,32 @@ public:
*
- * @param true if the RttiBase registered for this particular Managed class
+ * @param true if the RttiType registered for this particular Managed class
* may contain instance of the given type.
*/